@@ -22,7 +22,7 @@ fn get_all_category_sections() -> String {
         let mut fillings = Vec::new();
         fillings.push(("{{title}}", section_data.key.as_str()));
         fillings.push(("{{videos}}", videos.as_str()));
-        let section = template_filler::call("default_templates/category_section.html", fillings);
+        let section = template_filler::call("templates/category_section.html", fillings);
         section_content.push_str(&section);
     }
     section_content
@@ -47,13 +47,13 @@ fn get_videos_section_html(file: &str) -> String {
             fillings.push(("{{title}}", video.title.as_str()));
             fillings.push(("{{youtube_id}}", video.youtube_id.as_str()));
             fillings.push(("{{category}}", category.as_str()));
-            let video_html = template_filler::call("default_templates/youtube_video.html", fillings);
+            let video_html = template_filler::call("templates/youtube_video.html", fillings);
             yearly_videos.push_str(&video_html)
         }
         let year_string = year.to_string();
         year_fillings.push(("{{year}}", year_string.as_str()));
         year_fillings.push(("{{yearly_videos}}", yearly_videos.as_str()));
-        let year_html = template_filler::call("default_templates/year_section.html", year_fillings);
+        let year_html = template_filler::call("templates/year_section.html", year_fillings);
         html_content.push_str(&year_html);
     }
     return html_content;
