@@ -1,5 +1,7 @@
+mod assets_copier;
 mod data_extractor;
 mod file_content_loader;
+mod folder_copier;
 mod html_compiler;
 mod index_compiler;
 mod pages_compiler;
@@ -10,6 +12,7 @@ mod template_initializer;
 mod video_serializer;
 
 fn main() {
+    assets_copier::call();
     index_compiler::call();
     pages_compiler::call();
 }
